@@ -1,5 +1,7 @@
 import os
+from urlparse import urlparse, urlunparse
 
+from w3lib.url import path_to_file_uri
 from zope.interface import implements
 
 from .interfaces import IEnvironment
@@ -11,7 +13,7 @@ class Environment(object):
     def __init__(self, config, initenv=os.environ):
         self.dbs_dir = config.get('dbs_dir', 'dbs')
         self.logs_dir = config.get('logs_dir', 'logs')
-        self.items_dir = config.get('items_dir', 'items')
+        self.items_dir = config.get('items_dir','')
         self.jobs_to_keep = config.getint('jobs_to_keep', 5)
         if config.cp.has_section('settings'):
             self.settings = dict(config.cp.items('settings'))
@@ -31,9 +33,23 @@ class Environment(object):
         if self.logs_dir:
             env['SCRAPY_LOG_FILE'] = self._get_file(message, self.logs_dir, 'log')
         if self.items_dir:
-            env['SCRAPY_FEED_URI'] = self._get_file(message, self.items_dir, 'jl')
+            env['SCRAPY_FEED_URI'] = self._get_feed_uri(message, 'jl')
         return env
 
+    def _get_feed_uri(self, message, ext):
+        url = urlparse(self.items_dir)
+        if url.scheme.lower() in ['', 'file']:
+            return path_to_file_uri(self._get_file(message, url.path, ext))
+        return urlunparse((url.scheme,
+                           url.netloc,
+                           '/'.join([url.path,
+                                     message['_project'],
+                                     message['_spider'],
+                                     '%s.%s' % (message['_job'], ext)]),
+                           url.params,
+                           url.query,
+                           url.fragment))
+
     def _get_file(self, message, dir, ext):
         logsdir = os.path.join(dir, message['_project'], \
             message['_spider'])
